Crate pine_builtins

Crate pine_builtins 

Structs

Bar
Represents a single bar/candle of market data
DefaultPineOutput
Default implementation of PineOutput that supports all features

Enums

EvaluatedArg
Evaluated function argument
LogLevel
Log level

Functions

register_namespace_objects
Register all builtin namespaces as objects and global functions Returns namespace objects to be loaded as variables (e.g., “array”, “str”, “ta”) and global builtin functions (e.g., “na”) Each member stores the builtin function pointer as Value::BuiltinFunction
register_per_bar
Per-bar variables, rebuilt for each Bar and registered before it executes.

Type Aliases

BuiltinFn
Type signature for builtin functions (can be function pointers or closures)