Register all builtin namespaces as objects and global functions
Returns namespace objects to be loaded as variables (e.g., “array”, “str”, “ta”)
and global builtin functions (e.g., “na”)
Each member stores the builtin function pointer as Value::BuiltinFunction